#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/config.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2013-05-16 13:48:12 -0700 (Thu, 16 May 2013) $
##    $Rev: 11270 $
##
#
require 'yaml'
require 'ostruct'

module Lunaserv
  class Config < OpenStruct
    def initialize
      super YAML.load(File.read(File.join(Lunaserv.root, 'lunaserv.yml')))

      check_config
    end

    def check_config
      raise "tmpdir should point to the directory where temp files should be stored." unless respond_to? :tmpdir and File.directory? tmpdir
      raise "layerdir should point to the directory where layer config files are." unless respond_to? :layerdir and File.directory? layerdir
      raise "srsdir should point to the directory where srs config files are." unless respond_to? :srsdir and File.directory? srsdir
      raise "authmodules should indicate which authentication modules to load." unless respond_to? :authmodules
      raise "dbmodule should indicate which database module to load." unless respond_to? :dbmodule and File.exist?(File.join("lunaserv/db/#{dbmodule}.rb"))

      load_auth_modules
      load_db_module
    end

    def load_auth_modules
      Lunaserv.auth_modules = []
      authmodules.each do |name, config|
	Lunaserv.load_or_require "lunaserv/auth/#{config[:module]}.rb"
	Lunaserv.auth_modules << eval("Lunaserv::Auth::#{config[:module].split("_").collect(&:capitalize).join('')}").new(name, config)
      end
    end

    def load_db_module
      Lunaserv.load_or_require "lunaserv/db/#{dbmodule}.rb"
      Lunaserv.db_module = eval("Lunaserv::DB::#{dbmodule.split("_").collect(&:capitalize).join('')}")
    end
  end
end
