#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/handler/get_feature_info.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2014-01-07 14:32:17 -0700 (Tue, 07 Jan 2014) $
##    $Rev: 13466 $
##
#
require 'yaml'

module Lunaserv
  module Handler
    class GetFeatureInfo
      def self.run
	self.new.run
      end

      def initialize
	@response = Lunaserv.response
	@params = Lunaserv.params
	self
      end

      def get_layer_features(layer)
	layer.features(@params)[0..(@params[:feature_count]-1)]
      end

      def symbolize_keys(hash)
	data = {}
	hash.each do |k,v|
	  if k.is_a? Symbol
	    data[k] = v
	  else
	    data[k.to_s.downcase.to_sym] = v
	  end
	end
	data
      end

      def run
	case @params[:info_format]
	when "text/yaml"
	  @feature_data = {}
	  @params[:query_layers].each do |layer|
	    @feature_data[layer::LayerName] = get_layer_features(layer)
	  end
	  @response["Content-Type"] = "text/yaml"
	  @response.body = [@feature_data.to_yaml]
	when "text/html"
	  @response["Content-Type"] = "text/html"
	  body = ""
	  feature_data = @params[:query_layers].collect do |layer|
	    [layer, get_layer_features(layer)]
	  end
	  feature_data.each do |layer, layer_data|
	    if layer_data.empty?
	      body << "<div class=\"lunaserv_layer lunaserv_layer_#{layer::LayerName} lunaserv_nodata\">\n"
	      body << "  <div class=\"lunaserv_layer_name\">#{layer::LayerName} returned no features.</div>\n"
	      body << "</div>\n"
	    else
	      body << "<div class=\"lunaserv_layer lunaserv_layer_#{layer::LayerName}\">\n"
	      body << "  <div class=\"lunaserv_layer_name\">#{layer::LayerName}</div>\n"
	      body << "  <div class=\"lunaserv_features\">\n"
	      layer_data.each do |data|
		body << "    <div class=\"lunaserv_feature_info\">\n"
		if layer.respond_to? :feature_html_template
		  namespace = OpenStruct.new(symbolize_keys(data))
		  template = ERB.new(layer.feature_html_template)
		  body << "<!-- begin template for #{layer::LayerName} -->\n"
		  body << template.result(namespace.instance_eval { binding })
		  body << "\n<!-- end template for #{layer::LayerName} -->\n"
		else
		  title_key = data.keys.find {|k| k.to_s.downcase =~ /name/}
		  if title_key
		    body << "      <h4>#{data[title_key]}</h4>"
		  else
		    body << "      <h4>Feature</h4>"
		  end
		  body << "       <table>"
		  data.sort {|a,b| a[0].to_s.downcase<=>b[0].to_s.downcase}.each do |k,v|
		    next if ['index', :bbox, title_key].include? k
		    body << "         <tr><th>#{k}</th><td>#{v}</td></tr>"
		  end
		  body << "         <tr><th>BBox</th><td>#{data[:bbox].inspect}</td></tr>" if data[:bbox]
		  body << "       </table>"
		end
		body << "    </div>\n"
	      end
	      body << "  </div>\n"
	      body << "</div>\n"
	    end
	  end
	  @response.body = [body]
	when "application/vnd.ogc.gml"
	  @feature_data = {}
	  @params[:query_layers].each do |layer|
	    @feature_data[layer::LayerName+'_layer'] = get_layer_features(layer)
	  end
	  if Lunaserv.environment == 'development'
	    @response["Content-Type"] = "text/xml"
	  else
	    @response["Content-Type"] = "application/vnd.ogc.gml"
	  end

	  rhtml = ERB.new(File.read(File.join(Lunaserv.root, "templates/feature_info.xml.erb")))
	  rhtml.filename = "feature_info.xml.erb"
	  @response.body = [rhtml.result(binding)]
	end
      end
    end
  end
end
