#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/handler/get_map.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2016-03-15 11:49:19 -0700 (Tue, 15 Mar 2016) $
##    $Rev: 17383 $
##
#
module Lunaserv
  module Handler
    class GetMap
      def self.run
	new.run
      end

      def initialize
	@params = Lunaserv.params
	@response = Lunaserv.response
	@logger = Lunaserv.logger

	self
      end

      def run
	tmpdir = Lunaserv.tmpdir

        @params[:format] = 'image/tiff; mode=32bit' if @params[:layers].size == 1 and @params[:format] == 'image/tiff' and @params[:layers][0].superclass == Lunaserv::Layers::NumericBaseLayer

	if ['image/vicar', 'application/x-cesium-terrain', 'image/tiff; mode=32bit'].include? @params[:format]
	  raise Lunaserv::WmsError.new("Only one layer at a time can be rendered as vicar.") unless @params[:layers].size == 1
	  raise Lunaserv::WmsError.new("Only numeric layers can be rendered as vicar.") unless @params[:layers][0].superclass == Lunaserv::Layers::NumericBaseLayer
          @response["Content-Type"] = @params[:format]

          if @params[:format] =~ /tif/
            dest_file = File.join(tmpdir, "out.tif")
            open(dest_file, 'w') do |f|
              f.write(@params[:layers][0].render(@params))
            end

	    options = []
	    options += ['-p', @params[:proj]]
	    options += ['-x', @params[:bbox][0]]
	    options += ['-X', @params[:bbox][2]]
	    options += ['-y', @params[:bbox][1]]
	    options += ['-Y', @params[:bbox][3]]
	    options += ['-i', dest_file]
	    options += ['-r']
	    @logger.debug(options.inspect)
	    system "geotag", *options.collect(&:to_s)
            @response.body = [File.read(dest_file)]
          else
            @response.body = [@params[:layers][0].render(@params)]
          end
	else
	  if @params[:srs] =~ /^JMARS/
	    @logger.debug "JMARS detected"
	    @params[:transparent] = @params[:layers].detect { |l| l.opaque } ? false : true
	    @logger.debug "Transparent set to: #{@params[:transparent].inspect}"
	  end

	  path = "/opt/local/bin/" if File.executable? "/opt/local/bin/convert"
	  path = "/usr/bin/" if File.executable? "/usr/bin/convert"
	  command = "#{path}convert -depth 8 "

	  unless @params[:transparent]
	    command << "-background '#{@params[:bgcolor].sub('0x', '#')}' "
	  else
	    command << "-background none "
	  end

	  expiration_time = 86400*30
	  @params[:layers].each_with_index do |layer, index|
	    time = Time.now
	    if layer.respond_to? :refresh_time
	      expiration_time = layer.refresh_time.to_i if layer.refresh_time.to_i < expiration_time
	    else
	      expiration_time = 0
	    end
	    if layer.superclass == Lunaserv::Layers::NumericBaseLayer
	      open(File.join(tmpdir, "out.tif"), 'w') do |file|
		file.write layer.render(@params.merge({:format=>"image/tiff; mode=32bit"}))
	      end
	      system "convert #{File.join(tmpdir, "out.tif")} PNG32:#{File.join(tmpdir, "image-#{index}.png")}"
	    else
	      layer.render(@params.merge({:outfile=>File.join(tmpdir, "image-#{index}.png")}))
	    end
	    if @params[:extra][(layer::LayerName+"_alpha").to_sym].to_s.downcase == 'true'
	      command << "#{tmpdir}/image-#{index}.png -compose Multiply -composite -compose Over -flatten "
	    elsif @params[:extra][(layer::LayerName+"_opacity").to_sym].to_s =~ /^[.0-9]+$/ and @params[:extra][(layer::LayerName+"_opacity").to_sym].to_f >= 0 and @params[:extra][(layer::LayerName+"_opacity").to_sym].to_f <= 1
	      command << "\\( #{tmpdir}/image-#{index}.png -alpha set -channel Alpha -evaluate multiply #{@params[:extra][(layer::LayerName+"_opacity").to_sym].to_f} +channel \\) -flatten "
	    else
	      command << "#{tmpdir}/image-#{index}.png -flatten "
	    end
	    @logger.info "#{Time.now-time} seconds to render layer #{layer.wms_name}"
	    GC.start
	  end

	  dest_file = File.join(tmpdir, "out.#{@params[:format].split(';')[0].split('/')[1]}")
	  if dest_file =~ /png$/
	    command << "PNG32:#{dest_file}"
	  else
	    command << dest_file
	  end

	  @logger.debug command
	  system command

	  if @params[:format].split('/')[1] =~ /^tif/
	    options = []
	    options += ['-p', @params[:proj]]
	    options += ['-x', @params[:bbox][0]]
	    options += ['-X', @params[:bbox][2]]
	    options += ['-y', @params[:bbox][1]]
	    options += ['-Y', @params[:bbox][3]]
	    options += ['-i', dest_file]
	    options += ['-r']
	    @logger.debug(options.inspect)
	    system "geotag", *options.collect(&:to_s)
	  end

	  @response["Cache-Control"] = "#{Lunaserv.dispatcher.public ? "public" : "private"}, max-age=#{expiration_time}"

	  @response["Content-Type"] = @params[:format]
	  @response["Content-Disposition"] = "inline; filename=lunaserv.#{@params[:format].split(';')[0].split('/')[1]}"
	  @response.body = [File.read(dest_file)]
	end
      end
    end
  end
end
