#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2014-01-07 14:32:17 -0700 (Tue, 07 Jan 2014) $
##    $Rev: 13466 $
##
#
module Lunaserv
  module Layers
    @@layers = []

    def self.init
      logger = Lunaserv.logger
      layerdir = Lunaserv.config.layerdir

      Dir[File.join(File.dirname(__FILE__), 'layers', '*.rb')].sort do |a,b|
	if a =~ /master_layer.rb$/
	  -1
	elsif b =~ /master_layer.rb$/
	  1
	else
	  a<=>b
	end
      end.each do |base_layer|
	Lunaserv.load_or_require base_layer
      end

      @@layers = Dir[File.join(layerdir, "*/*.yml")].collect do |layer_file|
	begin
	  layer_def = YAML.load(open(layer_file).read)
	  layer_body = layer_file.split('/')[-2]
	  layer_def[:body] = layer_body
	  if layer_def[:dirname]
	    layer_def[:dir] = File.join(layerdir, layer_def[:body], layer_def[:dirname])
	  else
	    layer_def[:dir] = File.join(layerdir, layer_def[:body], layer_def[:wms_name])
	  end
	  layer = MasterLayer.create_layer(layer_def)
	  if layer.is_a? Array
	    logger.error { "The following errors occurred when loading #{layer_file}" }
	    layer.each do |message|
	      logger.error message
	    end
	    nil
	  else
	    layer
	  end
	rescue Exception => e
	  logger.error { "Error loading layer from #{layer_file}" }
	  logger.error { e.class }
	  logger.error { e.message }
	  logger.error { e.backtrace[0] }
	  nil
	end
      end.compact
    end

    def self.get_layer layer_name
      @@layers.detect do |l|
        l::LayerName == layer_name
      end
    end

    def self.get_all
      @@layers
    end
  end
end
