#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/grid_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2014-01-07 14:32:17 -0700 (Tue, 07 Jan 2014) $
#    $Rev: 13466 $
#
require 'open3'

module Lunaserv
  module Layers
    class GridBaseLayer < MasterLayer
      def initialize(options)
	@options = options
      end

      def render
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]
	options += override_option '-S', :stroke_color
	options += override_option '-F', :fill_color
	options += override_option '-B', :background
	options += override_option '-f', :font_size, '12'
	options += override_option '-d', :diameter, '8'
	options += override_option '-a', :padding, '5'

	Open3.popen3 "map_vector_layer", *(options.collect(&:to_s)) do |stdin, stdout, stderr|
	  -180.step(180,spacing) do |lon|
	    old_point = nil
	    -90.step(90,1) do |lat|
	      if old_point
		stdin.puts "o:2:#{old_point[0].to_f},#{old_point[1].to_f};#{lon.to_f},#{lat.to_f}"
	      end
	      old_point = [lon,lat]
	    end
	  end

	  -90.step(90,spacing) do |lat|
	    old_point=nil
	    -180.step(180,1) do |lon|
	      if old_point
		stdin.puts "o:2:#{old_point[0].to_f},#{old_point[1].to_f};#{lon.to_f},#{lat.to_f}"
	      end
	      old_point = [lon,lat]
	    end
	  end

	  stdin.close
	  stdout.read
	end
      end

      def self.check_defs(layer_def, messages)
	[:spacing, :stroke_color].each do |key|
	  messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	end
      end
    end
  end
end
