#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/illumination_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2014-01-07 14:32:17 -0700 (Tue, 07 Jan 2014) $
#    $Rev: 13466 $
#
module Lunaserv
  module Layers
    class IlluminationBaseLayer < MasterLayer
      def initialize(options)
	@options = options
	set_config
      end

      def set_config
	@basemaps = self.basemaps.collect {|file| File.join(self.dir, file)}
      end

      def get_point
	lon = @options[:extra]["#{self.body}_#{self.wms_name}_longitude".to_sym]  
	lat = @options[:extra]["#{self.body}_#{self.wms_name}_latitude".to_sym]  
	if lon and lat
	  [lon, lat]
	else
	  point_call = [ self.body ]
	  point_call = [ 'moon' ] if self.body == 'luna'
	  if @options[:extra][:time]
	    point_call << @options[:extra][:time]
	  elsif self.respond_to? :default_time
	    point_call << self.default_time
	  end

	  Lunaserv.logger.debug "#{Lunaserv.root}/subsolar/get_point.rb #{point_call.collect(&:to_s).join(" ")}"
	  Open3.popen3 "#{Lunaserv.root}/subsolar/get_point.rb", *point_call.collect(&:to_s) do |stdin, stdout, stderr|
	    stdin.close
	    output = stdout.read
	    Lunaserv.logger.debug stderr.read
	    Lunaserv.logger.debug output
	    output.split(' ')
	  end
	end
      end

      def render
	lon, lat = get_point

	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-w', @options[:width]]
	options += ['-h', @options[:height]]
	options += ['-o', @options[:outfile]]
	options += ['-L', lon]
	options += ['-l', lat]
	options += ['--variance', self.elevation_variance_km]
	options += ['--radius', self.radius_km]
	options += ['-m'] if self.units == :meters
	options += ['-r'] if self.data_form == :radii
	options += override_option '-S', :shadow_color, '000000ff'
	options += override_option '-D', :dark_color, '000000ff'
	options += override_option '-I', :light_color, '00000000'
	options += override_option '--photo-function', :photometric_function, 'lambert'
	options += override_option '--solar-distance', :solar_distance, '149597871'

	@basemaps.each {|b| options += ['-i', b]}

	Lunaserv.logger.debug((["map_illum_layer"] + options.collect(&:to_s)).join(" "))
	system "map_illum_layer", *(options.collect(&:to_s))
      end

      def self.check_defs(layer_def, messages)
	[:elevation_variance_km, :radius_km, :units, :data_form].each do |key|
	  messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	end
	messages << "Units must be either :meters or :kilometers" unless [:meters, :kilometers].include? layer_def[:units]
	messages << "Data_form must be either :radii or :offset" unless [:radii, :offset].include? layer_def[:data_form]
	messages << "Basemaps must be an array" unless layer_def[:basemaps].is_a? Array
	messages << "Basemaps must have at least one map listed" if layer_def[:basemaps].empty?
	layer_def[:basemaps].each do |basemap|
	  messages << "Basemap does not exist: #{File.join(layer_def[:dir], basemap)}" unless File.exist? File.join(layer_def[:dir], basemap)
	end
      end
    end
  end
end
