#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/raster_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2014-01-07 14:32:17 -0700 (Tue, 07 Jan 2014) $
#    $Rev: 13466 $
#
module Lunaserv
  module Layers
    class RasterBaseLayer < MasterLayer
      def initialize(options)
	@options = options

	set_config
      end

      def set_config
	@basemaps = self.basemaps.collect {|file| File.join(self.dir, file)}
      end

      def render
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]
	@basemaps.each {|b| options += ['-b', b]}

	Lunaserv.logger.debug((["map_raster_layer"] +(options.collect(&:to_s))).join(' '))
	system "map_raster_layer", *(options.collect(&:to_s))
      end

      def self.check_defs(layer_def, messages)
	messages << "Basemaps must be an array" unless layer_def[:basemaps].is_a? Array
	messages << "Basemaps must contain at least one map" if layer_def[:basemaps].empty?
	layer_def[:basemaps].each do |basemap|
	  messages << "File does not exist: #{File.join(layer_def[:dir], basemap)}"  unless File.exist? File.join(layer_def[:dir], basemap)
	end
      end
    end
  end
end
