#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/stamp_db_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2016-03-10 18:35:30 -0700 (Thu, 10 Mar 2016) $
#    $Rev: 17376 $
#
require 'open3'

module Lunaserv
  module Layers
    class StampDbBaseLayer < MasterLayer
      def initialize(options)
	@options = options
      end

      def render
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]

        @dbh = Lunaserv.db_module.new(self)
        tmp_query = apply_filters stamp_query
        @stamps = [''] + @dbh.exec(tmp_query).collect { |row| row['stamp_file'] }

	slices = 0
	files = []
	work = []
	@stamps.each_slice(50) do |slice|
	  slices += 1
	  files << @options[:outfile]+"_#{slices}.png"
	  my_options = options + ['-o', files[-1]]
	  work << {:options=>my_options, :slice=>slice}
	end

	Parallel.map(work, :in_processes=>8) do |work_data|
	  my_options = work_data[:options]
	  slice = work_data[:slice]
	  Lunaserv.logger.debug((["map_raster_layer"] + (my_options.collect(&:to_s))).join(' '))
	  Open3.popen3 "map_raster_layer", *(my_options.collect(&:to_s)) do |stdin, stdout, stderr|
	    begin
	      slice.each do |stamp|
		stdin.puts stamp
		stdout.read_nonblock rescue nil
		stderr.read_nonblock rescue nil
	      end
	    rescue Errno::EPIPE
	    end

	    stdin.close
	    stderr.read
	    stdout.read
	  end
	end

	if slices == 1
	  FileUtils.mv files[0], @options[:outfile]
	else
	  path = "/opt/local/bin/" if File.executable? "/opt/local/bin/convert"
	  path = "/usr/bin/" if File.executable? "/usr/bin/convert"
	  command = "#{path}convert -depth 8 "
	  command << "-background none "
	  files.reverse.each do |file|
	    command << "#{file} -flatten "
	  end
	  
	  command << "PNG32:#{@options[:outfile]}"
	  Lunaserv.logger.debug command
	  system command
	end
      end

      def self.check_defs(layer_def, messages)
	[:dbname, :dbuser, :dbpassword, :dbhost, :stamp_query].each do |key|
	  messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	end
      end

      def features
	shapes = []

	@dbh = Lunaserv.db_module.new(self)

	tmp_query = apply_filters feature_search_query

	options = []
	options += ['-r'] if self.respond_to? :units and self.units == :radians
	options += ['-p', @options[:proj]]
	Open3.popen3 "map_get_vector_bbox", *(options.collect(&:to_s)) do |stdin, stdout, stderr|
	  stdin.sync = true
	  stdout.sync = true
	  shapes = @dbh.exec(tmp_query).collect do |row|
	    if row['points'].count(';') == 0
	      stdin.print "p:"
	    elsif row['type'] == 'open'
	      stdin.print "o:#{row['points'].count(';')+1}:"
	    else
	      stdin.print "c:#{row['points'].count(';')+1}:"
	    end
	    stdin.puts row['points']
	    data = stdout.gets.strip
	    if data =~ /^Error/i
	      row[:bbox] = []
	    else
	      row[:bbox] = data.split(',').collect(&:to_f)
	    end
	    row
	  end
	end

	shapes
      end
    end
  end
end
