#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/vector_db_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2016-01-27 15:26:55 -0700 (Wed, 27 Jan 2016) $
#    $Rev: 17239 $
#
require 'open3'

module Lunaserv
  module Layers
    class VectorDbBaseLayer < MasterLayer
      def initialize(options)
	@options = options
      end

      def features
	shapes = []

	@dbh = Lunaserv.db_module.new(self)

	tmp_query = apply_filters feature_search_query
        Lunaserv.logger.debug tmp_query

	options = []
	options += ['-r'] if self.units == :radians
	options += ['-p', @options[:proj]]
	Open3.popen3 "map_get_vector_bbox", *(options.collect(&:to_s)) do |stdin, stdout, stderr|
	  stdin.sync = true
	  stdout.sync = true
	  shapes = @dbh.exec(tmp_query).collect do |row|
	    if row['label']
	      stdin.puts "a:#{row['points']}:#{row['label']}"
	    else
	      if row['points'].count(';') == 0
		stdin.print "p:"
	      elsif row['type'] == 'open'
		stdin.print "o:#{row['points'].count(';')+1}:"
	      else
		stdin.print "c:#{row['points'].count(';')+1}:"
	      end
	      stdin.puts row['points']
	    end
	    data = stdout.gets.strip
	    if data =~ /^Error/i
	      row[:bbox] = []
	    else
	      row[:bbox] = data.split(',').collect(&:to_f)
	    end
	    row
	  end
	end

	shapes
      end

      def render
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]
	options += ['-r'] if self.units == :radians
	options += ['-s'] if self.respond_to? :show_point and self.show_point.to_s == "true"
	options += ['-T', File.join(Lunaserv.root, Lunaserv.config.font)]
	options += override_option '-S', :stroke_color
	options += override_option '-F', :fill_color
	options += override_option '-P', :point_color
	options += override_option '-B', :background
	options += override_option '-f', :font_size, '12'
	options += override_option '-d', :diameter, '8'
	options += override_option '-a', :padding, '5'
	options += override_option '-m', :limit

	Lunaserv.logger.debug "map_vector_layer " + (options.collect(&:to_s)).join(' ')
	Open3.popen3 "map_vector_layer", *(options.collect(&:to_s)) do |stdin, stdout, stderr|
	  @dbh = Lunaserv.db_module.new(self)
	  tmp_query = apply_filters shape_query
	  Lunaserv.logger.debug tmp_query

	  @dbh.exec(tmp_query).each do |row|
	    begin
	      if row['label']
		stdin.puts "a:#{row['points']}:#{row['label']}"
	      else
		if row['points'].count(';') == 0
		  stdin.print "p:"
		elsif row['type'] == 'open'
		  stdin.print "o:#{row['points'].count(';')+1}:"
		else
		  stdin.print "c:#{row['points'].count(';')+1}:"
		end
		stdin.puts row['points']
	      end
	    rescue Errno::EPIPE
	      break
	    end
	  end

	  stdin.close
	  puts stdout.read
	end
      end

      def self.check_defs(layer_def, messages)
	[:units, :stroke_color, :dbname, :dbuser, :dbpassword, :dbhost, :shape_query].each do |key|
	  messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	end
      end
    end
  end
end
