#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/vector_file_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2016-01-27 15:26:55 -0700 (Wed, 27 Jan 2016) $
#    $Rev: 17239 $
#
require 'open3'

module Lunaserv
  module Layers
    class VectorFileBaseLayer < MasterLayer
      def initialize(options)
	@options = options
      end

      def render
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]
	options += ['-r'] if self.units == :radians
	options += ['-T', File.join(Lunaserv.root, Lunaserv.config.font)]
	options += override_option '-S', :stroke_color
	options += override_option '-F', :fill_color
	options += override_option '-B', :background
	options += override_option '-P', :point_color
	options += override_option '-f', :font_size, '12'
	options += override_option '-d', :diameter, '8'
	options += override_option '-a', :padding, '5'
	options += override_option '-m', :limit
	options += ['-s'] if self.respond_to? :show_point and self.show_point
	options += ['-l'] if self.respond_to? :label_left and self.label_left

	Lunaserv.logger.debug options.inspect

	Open3.popen3 "map_vector_layer", *(options.collect(&:to_s)) do |stdin, stdout, stderr|
	  begin
	    stdin.write(open(File.join(self.dir, self.file)).read)
	  rescue Errno::EPIPE
	  end

	  stdin.close
	  puts stdout.read
	end
      end

      def self.check_defs(layer_def, messages)
	[:units, :stroke_color, :file].each do |key|
	  messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	end
	messages << "File does not exist: #{File.join(layer_def[:dir], layer_def[:file])}" unless File.exist? File.join(layer_def[:dir], layer_def[:file])
      end
    end
  end
end
