#
# $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/layers/vector_shapefile_base_layer.rb $
# 
# Copyright (C) 2013 by Arizona State University and Mark Robinson.
# All rights reserved.
#
# This file has been released under the modified BSD license.
# See COPYING in the distribution package for details.
#
# Author: Nick Estes <nme@ser.asu.edu>
#
# $Author: nme $
#   $Date: 2016-01-27 15:26:55 -0700 (Wed, 27 Jan 2016) $
#    $Rev: 17239 $
#
module Lunaserv
  module Layers
    class VectorShapefileBaseLayer < MasterLayer
      def initialize(options)
	@options = options
      end

      def features
	lon, lat, radius = get_pixel_circle(@options[:x], @options[:y])

	radius *= feature_search_radius

	options = base_options
	options += ['-L', lon]
	options += ['-l', lat]
	options += ['-r', radius]

	Lunaserv.logger.debug((["map_query_shapefile"]+options.map(&:to_s)).join(" "))
	data = YAML.load(IO.popen(["map_query_shapefile"]+options.map(&:to_s)).read)
	Lunaserv.logger.debug data.inspect
	data['shapes']
      end

      def render
	options = base_options
	options += ['-W', @options[:width]]
	options += ['-H', @options[:height]]
	options += ['-o', @options[:outfile]]
	options += ['-T', File.join(Lunaserv.root, Lunaserv.config.font)]
	options += override_option '-f', :font_size, '12'
	options += override_option '-P', :padding, '5'
	options += override_option '-S', :stroke_color
	options += override_option '-F', :fill_color
	options += override_option '-B', :background
	options += override_option '-d', :diameter, 8
	options += override_option '-L', :label_template

	puts "map_shapefile_layer" + (options.collect(&:to_s)).join(' ')
	system "map_shapefile_layer", *(options.collect(&:to_s))
      end

      def self.check_defs(layer_def, messages)
	if layer_def[:shapefile] and layer_def[:shapefile_query]
	  messagess << "Only one of shapefile or shapefile_query may be specified"
	elsif layer_def[:shapefile]
	  messagess << "Shapefile not found: #{File.join(layer_def[:dir], layer_def[:shapefile]) }" unless File.exist? File.join(layer_def[:dir], layer_def[:shapefile])
	elsif layer_def[:shapefile_query]
	  [:dbname, :dbuser, :dbpassword, :dbhost].each do |key|
	    messages << "Missing required key: #{key}" unless layer_def.keys.include? key
	  end
	else
	  messages << "Either :shapefile or :shapefile_query must be specified."
	end
	messages << "Missing required key: #{key}" unless layer_def[:stroke_color]
      end

      private

      def base_options
	options = []
	options += ['-p', @options[:proj]]
	options += ['-x', @options[:bbox][0]]
	options += ['-X', @options[:bbox][2]]
	options += ['-y', @options[:bbox][1]]
	options += ['-Y', @options[:bbox][3]]

	if respond_to? :shapefile
	  options += ['-s', File.join(dir, shapefile)]
	else
	  @dbh = Lunaserv.db_module.new(self)
	  @dbh.exec(apply_filters shapefile_query).each do |row|
	    options += ['-s', row['shapefile']]
	  end
	end

	options
      end
    end
  end
end
