#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv/projections.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2015-05-08 09:31:42 -0700 (Fri, 08 May 2015) $
##    $Rev: 16214 $
##
#
module Lunaserv
  @@projections = []

  class Projections
    def self.get_all
      @@projections
    end

    def self.init
      projectiondir = Lunaserv.config.srsdir
      logger = Lunaserv.logger

      projections = []

      Dir[File.join(projectiondir, "*.yml")].each do |projection_file|
	projection_data = YAML.load(open(projection_file))
	if projection_data[:iau_code]
	  [:a, :b, :body].each do |key|
	    unless projection_data.has_key? key
	      logger.error "Projection file #{projection_file} failed to load."
	      next
	    end
	  end
	  projections << ["IAU2000:#{projection_data[:iau_code]}00", "IAU2000:#{projection_data[:iau_code]}00", "+proj=longlat +a=#{projection_data[:a]} +b=#{projection_data[:b]} +no_defs", projection_data[:body]]
	  projections << ["IAU2000:#{projection_data[:iau_code]}14", "IAU2000:#{projection_data[:iau_code]}14", "+proj=sinu +lon_0=0 +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
	  projections << ["IAU2000:#{projection_data[:iau_code]}18", "IAU2000:#{projection_data[:iau_code]}18", "+proj=stere +lat_0=90 +lon_0=0 +k=1 +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
	  projections << ["IAU2000:#{projection_data[:iau_code]}20", "IAU2000:#{projection_data[:iau_code]}20", "+proj=stere +lat_0=-90 +lon_0=0 +k=1 +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
          projections << ["IAU2000:#{projection_data[:iau_code]}22", "IAU2000:#{projection_data[:iau_code]}22", "+proj=moll +lon_0=0 +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]}} +units=m +no_defs", projection_data[:body]]
	  projections << [/^IAU2000:#{projection_data[:iau_code]}66,9001,([-+]?\d*?\.?\d*?),([-+]?\d*\.?\d*?)$/, "IAU2000:#{projection_data[:iau_code]}66,9001,c_lon,c_lat", "+proj=ortho +lat_0=\#{$2} +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
	  projections << [/^IAU2000:#{projection_data[:iau_code]}66,([-+]?\d*?\.?\d*?),([-+]?\d*\.?\d*?)$/, "IAU2000:#{projection_data[:iau_code]}66,c_lon,c_lat", "+proj=ortho +lat_0=\#{$2} +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
          projections << [/^IAU2000:#{projection_data[:iau_code]}60,9001,([-+]?\d*?\.?\d*?)$/, "IAU2000:#{projection_data[:iau_code]}60,9001,c_lon", "+proj=sinu +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
          projections << [/^IAU2000:#{projection_data[:iau_code]}60,([-+]?\d*?\.?\d*?)$/, "IAU2000:#{projection_data[:iau_code]}60,c_lon", "+proj=sinu +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]} +units=m +no_defs", projection_data[:body]]
          projections << [/^IAU2000:#{projection_data[:iau_code]}80,9001,([-+]?\d*?\.?\d*)$/, "IAU2000:#{projection_data[:iau_code]}80,9001,c_lon", "+proj=moll +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]}} +units=m +no_defs", projection_data[:body]]
          projections << [/^IAU2000:#{projection_data[:iau_code]}80,([-+]?\d*?\.?\d*)$/, "IAU2000:#{projection_data[:iau_code]}80,c_lon", "+proj=moll +lon_0=\#{$1} +x_0=0 +y_0=0 +a=#{projection_data[:a]} +b=#{projection_data[:b]}} +units=m +no_defs", projection_data[:body]]
	else
	  [:human_name, :srs_match, :srs_proj, :body].each do |key|
	    unless projection_data.has_key? key
	      logger.error "Projection file #{projection_file} failed to load."
	      next
	    end
	  end
	  projections << [projection_data[:srs_match], projection_data[:human_name], projection_data[:srs_proj], projection_data[:body]]
	end
      end

      @@projections = projections.collect do |proj_data|
	proj_data << Proc.new do
	  `map_calc_extents -c /tmp/lunaserv_extents_cache -p "#{proj_data[2].gsub(/\#\{.*?\}/, '0.0')}"`.strip.split(',')
	end
      end
    end

    def self.get_srs(srs)
      match, string, proj = @@projections.detect do |match, string, proj|
	match === srs or srs == string
      end
      proj4 = eval("\"#{proj}\"")
      Lunaserv.logger.debug proj4.inspect
      return proj4 if match
    end
  end
end

