#
## $URL: https://repos.ser.asu.edu/svn/lroc/lunaserv/tags/release_20160316/lunaserv_application.rb $
## 
## Copyright (C) 2013 by Arizona State University and Mark Robinson.
## All rights reserved.
##
## This file has been released under the modified BSD license.
## See COPYING in the distribution package for details.
##
## Author: Nick Estes <nme@ser.asu.edu>
##
## $Author: nme $
##   $Date: 2014-08-27 09:43:41 -0700 (Wed, 27 Aug 2014) $
##    $Rev: 15109 $
##
#
require 'rubygems'
require 'bundler/setup'
require 'erb'
require 'logger'
require 'fileutils'

module Lunaserv
  FORMATS = ["image/png", "image/tiff", "image/jpeg", "image/gif", "image/pnm", 'image/vicar', 'application/x-cesium-terrain', "image/tiff; mode=32bit"]

  class << self
    attr_accessor :application, :dispatcher, :config, :auth_modules, :db_module, :logger, :environment, :root, :request, :response, :rack_environment, :tmpdir, :params

    def load_or_require file
      if Lunaserv.environment == 'development'
	load file
      else
	require file
      end
    end
  end

  class Application
    def self.call env
      new(env).run
    end

    def initialize env
      Lunaserv.rack_environment = env
      Lunaserv.environment = ENV['RACK_ENV'] || ENV['PASSENGER_ENVIRONMENT'] || ENV['LUNASERV_ENVIRONMENT'] || 'development'
      Lunaserv.request = Rack::Request.new(env)
      Lunaserv.response = Rack::Response.new
      Lunaserv.logger = Logger.new("log/#{Lunaserv.environment}.log")
      #Lunaserv.logger.level = Lunaserv.environment == 'production' ? Logger::INFO : Logger::DEBUG
      Lunaserv.logger.level = Logger::DEBUG
      Lunaserv.root = File.dirname(File.expand_path __FILE__)

      Lunaserv.load_or_require 'lunaserv/config.rb'
      Lunaserv.config = Lunaserv::Config.new
      self
    end

    def dev?
      environment == 'development'
    end

    def run
      begin
	Lunaserv.load_or_require 'lunaserv/dispatcher.rb'
	Lunaserv::Dispatcher.run
	Lunaserv.response.finish
      rescue Exception=>e
	@exception = e
	Lunaserv.logger.fatal "#{e.class}: #{e.message} - #{e.backtrace.join("\n")}"
	@response = Rack::Response.new
	Lunaserv.response.status = 200
	Lunaserv.response["Content-Type"] = "text/html"

	rhtml = ERB.new(File.read(File.join(Lunaserv.root, "templates/500.erb")))
	rhtml.filename = "500.erb"
	Lunaserv.response.body = [rhtml.result(binding)]
	Lunaserv.response.finish
      end
    end
  end
end
